#include "widget.h"
#include "ui_widget.h"
#include <iostream>
using namespace  std;

// ____________________________________________________________ Application interface constructeur
Widget::Widget(QWidget *parent) :
    QWidget(parent),
    ui(new Ui::Widget)
{
    ui->setupUi(this);

    // le timer
    timer = new QTimer(this);
    connect(timer, SIGNAL(timeout()), this, SLOT(onTimer()));

    // l'IHM
    this->setWindowTitle("QWT example - 1.00 - plot");

    // a simple plot
    plotTemp = new QwtPlot(this);
    plotTemp->setGeometry(0, 0, ui->frameplot->width(), ui->frameplot->height());
    plotTemp->setTitle( "Data" );
    plotTemp->setCanvasBackground( Qt::white );
    plotTemp->setAxisScale( QwtPlot::xBottom, 0.0, 1000);
    plotTemp->setAxisScale( QwtPlot::yLeft, -50, 100 );
    plotTemp->insertLegend( new QwtLegend() );

    // the grid - axes
    QwtPlotGrid *grid = new QwtPlotGrid();
    grid->attach( plotTemp );

    // the light curve
    lightCurve = new QwtPlotCurve();
    lightCurve->setTitle( "Light (lux)" );
    lightCurve->setPen( Qt::blue, 2 ),
    lightCurve->setRenderHint( QwtPlotItem::RenderAntialiased, true );
    //  curve and symbols
    QwtSymbol *symbol = new QwtSymbol(QwtSymbol::Ellipse, QBrush(Qt::yellow),
                                       QPen(Qt::red,1), QSize(3, 3));
    lightCurve->setSymbol( symbol );
    lightCurve->attach(plotTemp);

    // the hygrometry curve
    hygroCurve = new QwtPlotCurve();
    hygroCurve->setTitle( "Soil Hygrometry (%)" );
    hygroCurve->setPen( Qt::green, 2 ),
    hygroCurve->setRenderHint( QwtPlotItem::RenderAntialiased, true );
    hygroCurve->attach(plotTemp);

    // hide the support frame
    plotTemp->show();

    // time origin
    t = 0;

    timer->start(10);
}

//                                      Destructeur
Widget::~Widget()
{
    delete ui;
}

// timer interrup function
void Widget::onTimer(){
// the Light curve = sin
float lux = 20*sin(2*M_PI/400*t);
lightPoints.push_back(QPointF(t, lux));
lightCurve->setSamples(lightPoints);
// the hygro curve = cos
float hygro = 50*cos(2*M_PI/(600/t*100)*t)+50;        // singularity for t=0
hygroPoints.push_back(QPointF(t, hygro));
hygroCurve->setSamples(hygroPoints);
plotTemp->replot();
t++;
// the end of the x-axis ---> stop
if (t>=plotTemp->axisInterval(1).maxValue()) timer->stop();
}

